@@ -1,5 +1,5 @@
 package Neovim::Ext;
-$Neovim::Ext::VERSION = '0.03';
+$Neovim::Ext::VERSION = '0.04';
 use strict;
 use warnings;
 use base qw/Class::Accessor/;
@@ -50,12 +50,20 @@ sub _setup_logging
 
 	if ($name eq 'script')
 	{
+		my $stderr;
+		if ($ENV{NVIM_PERL_LOG_FILE})
+		{
+			open $stderr, '>', $ENV{NVIM_PERL_LOG_FILE};
+		}
+
 		# Redirect STDERR
 		tie (*STDERR => 'Neovim::Ext::Tie::Stream', sub
 			{
 				my ($data) = @_;
 				$data .= "\n" if (index ($data, "\n") == -1);
 				$nvim->err_write ($data, async_ => 1);
+
+				print $stderr $data if ($stderr);
 			}
 		);
 
@@ -469,7 +477,7 @@ Neovim::Ext - Perl bindings for neovim
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 DESCRIPTION
 
